==> deepin-boot-maker_5.6.5+dfsg.orig.tar.gz: deepin-boot-maker_5.6.5+dfsg/src/help/deepin-boot-maker/boot-maker/zh_TW/boot-maker.md <==
# 開機碟製作器|../common/deepin_boot_maker_96.svg|

## 概述

開機碟製作器是一款將系統鏡像文件寫入隨身碟等安裝介質的小工具，介面簡潔、操作簡單。



## 使用入門

透過以下方式執行或關閉開機碟製作器，或者建立開機碟製作器的捷徑。

### 執行開機碟製作器

1. 單擊任務欄上的啟動器 ![deepin_launcher](../common/deepin_launcher.svg)，進入啟動器介面。
2. 上下滾動滑鼠滾輪瀏覽或透過搜尋，找到「開機碟製作器」按鈕 ![deepin_boot_maker](../common/deepin_boot_maker.svg)，單擊開啟。
3. 右鍵單擊 ![deepin_boot_maker](../common/deepin_boot_maker.svg)，您可以：

   - 單擊 **建立桌面捷徑**，在桌面建立捷徑。
   - 單擊 **釘選到Dock**，將應用程式固定到Dock。
   - 單擊 **開機啟動**，將應用程式添加到開機啟動項，在電腦開機時自動執行該應用。

### 關閉開機碟製作器

- 在開機碟製作器視窗，單擊 ![close](../common/close.svg)，關閉開機碟製作器。
- 在任務欄右鍵單擊 ![deepin_boot_maker](../common/deepin_boot_maker.svg)，選擇 **關閉所有** 來關閉開機碟製作器。
- 在開機碟製作器介面，單擊 ![icon_menu](../common/icon_menu.svg)，選擇 **離開** 來關閉開機碟製作器。

## 操作介紹

### 執行準備工作

1. 在統信UOS官網下載最新的系統鏡像文件。
2. 準備一個至少8GB的隨身碟。
3. 執行開機碟製作器。
   - 統信UOS系統中已經預設整合了開機碟製作器，可以直接在啟動器中找到並使用。
   - Windows系統可以從光碟鏡像中解壓 xxx-boot-maker.exe 到電腦中使用。
   - 您也可以瀏覽統信UOS官網下載指定版本的開機碟製作器來使用。

### 選擇ISO檔案

您可以透過以下兩種方式選擇鏡像文件：

- 單擊 **選擇一個ISO檔案**，選中已下載的鏡像文件後單擊 **下一步**。
- 直接將鏡像文件拖曳到製作工具介面，然後單擊 **下一步**。



![0|selectfile](fig/selectfile.png)

### 選擇分區

選中製作開機碟使用的隨身碟或分區，然後單擊 **開始** 或 **返回**  按鈕。

   - 開始製作：建議勾選 **格式化分區**，製作前請儲存好隨身碟的資料。
   - 返回：返回到選擇鏡像介面。

![0|boot-maker](fig/select_disk.png)

### 製作成功

製作過程需要一定的時間，請耐心等待，製作時請不要移除磁碟或關機。待進度條滿格，出現 **製作成功** 的提示，表明開機碟已經製作完成。

![boot-maker](fig/making.png)

![recoder](fig/success.png)

### 製作失敗

如果製作失敗，可能由如下情況導致：

- 磁碟格式錯誤
- 磁碟空間錯誤
- 磁碟掛載錯誤
- 解壓鏡像錯誤



![boot-maker](fig/failed.png)



![boot-maker](fig/failed02.png)



當出現未知錯誤時，製作失敗窗口會出現 “提交回饋” 按鈕。單擊 **提交回饋** 後，跳轉到相關論壇進行問題回饋。



## 主選單

在主選單中，您可以切換視窗主題、查看說明手冊，了解開機碟製作器的更多訊息。

### 主題

視窗主題包含亮色主題、暗色主題和系統主題。

1. 在開機碟製作器介面，單擊 ![icon_menu](../common/icon_menu.svg)。
2. 單擊 **主題**，選擇一個主題顏色。

### 說明

查看說明手冊，透過幫助進一步讓您了解和使用開機碟製作器。

1. 在開機碟製作器介面，單擊 ![icon_menu](../common/icon_menu.svg)。
2. 單擊 **說明**。
3. 查看關於開機碟製作器的說明手冊。

### 關於

1. 在開機碟製作器介面，單擊 ![icon_menu](../common/icon_menu.svg)。
2. 單擊 **關於**。
3. 查看關於開機碟製作器的版本和介紹。

### 離開

1. 在開機碟製作器介面，單擊 ![icon_menu](../common/icon_menu.svg)。
2. 單擊 **離開**。

==> deepin-boot-maker_5.6.12+dfsg.orig.tar.gz: deepin-boot-maker_5.6.12+dfsg/src/help/deepin-boot-maker/boot-maker/zh_TW/boot-maker.md <==
# 開機碟製作器|deepin-boot-maker|

## 概述

開機碟製作器是一款將系統鏡像文件寫入隨身碟等安裝介質的小工具，介面簡潔、操作簡單。



## 使用入門

透過以下方式執行或關閉開機碟製作器，或者建立開機碟製作器的捷徑。

### 執行開機碟製作器

1. 單擊任務欄上的啟動器 ![deepin_launcher](../common/deepin_launcher.svg)，進入啟動器介面。
2. 上下滾動滑鼠滾輪瀏覽或透過搜尋，找到「開機碟製作器」按鈕 ![deepin_boot_maker](../common/deepin_boot_maker.svg)，單擊開啟。
3. 右鍵單擊 ![deepin_boot_maker](../common/deepin_boot_maker.svg)，您可以：

   - 單擊 **建立桌面捷徑**，在桌面建立捷徑。
   - 單擊 **釘選到Dock**，將應用程式固定到Dock。
   - 單擊 **開機啟動**，將應用程式添加到開機啟動項，在電腦開機時自動執行該應用。

### 關閉開機碟製作器

- 在開機碟製作器視窗，單擊 ![close](../common/close.svg)，關閉開機碟製作器。
- 在任務欄右鍵單擊 ![deepin_boot_maker](../common/deepin_boot_maker.svg)，選擇 **關閉所有** 來關閉開機碟製作器。
- 在開機碟製作器介面，單擊 ![icon_menu](../common/icon_menu.svg)，選擇 **離開** 來關閉開機碟製作器。

## 操作介紹

### 執行準備工作

1. 到官網下載最新的系統鏡像文件。
2. 準備一個至少8GB的隨身碟。
3. 獲取啟動盤製作工具。
   - 系統預裝了啟動盤製作工具，在啟動器中查找。
   - 訪問官網下載指定版本的啟動盤製作工具。
   - Windows系統可以從光碟鏡像中解壓 xxx_boot_maker.exe 到電腦中。

### 選擇ISO檔案

您可以透過以下兩種方式選擇鏡像文件：

- 單擊 **選擇一個ISO檔案**，選中已下載的鏡像文件後單擊 **下一步**。
- 直接將鏡像文件拖曳到製作工具介面，然後單擊 **下一步**。



![0|selectfile](fig/selectfile.png)

### 選擇分區

選中製作啟動盤的隨身碟，如果隨身碟有多個分區，只能選擇第一個分區。單擊**開始**或**返回**按鈕。

   - 開始製作：建議勾選 **格式化分區**，製作前請儲存好隨身碟的資料。
   - 返回：返回到選擇鏡像介面。

![0|boot-maker](fig/select_disk.png)

### 製作成功

製作過程需要一定的時間，請耐心等待，製作時請不要移除磁碟或關機。待進度條滿格，出現 **製作成功** 的提示，表明開機碟已經製作完成。

![boot-maker](fig/making.png)

![recoder](fig/success.png)

### 製作失敗

如果製作失敗，可能由如下情況導致：

- 磁碟格式錯誤
- 磁碟空間錯誤
- 磁碟掛載錯誤
- 解壓鏡像錯誤



![boot-maker](fig/fail.png)


當出現未知錯誤時，製作失敗窗口會出現「意見回應」按鈕。單擊 **意見回應** 後，跳轉到相關論壇進行問題回饋。



## 主選單

在主選單中，您可以切換視窗主題、查看說明手冊，了解開機碟製作器的更多訊息。

### 主題

視窗主題包含亮色主題、暗色主題和系統主題。

1. 在開機碟製作器介面，單擊 ![icon_menu](../common/icon_menu.svg)。
2. 單擊 **主題**，選擇一個主題顏色。

### 說明

查看說明手冊，透過幫助進一步讓您了解和使用開機碟製作器。

1. 在開機碟製作器介面，單擊 ![icon_menu](../common/icon_menu.svg)。
2. 單擊 **說明**。
3. 查看關於開機碟製作器的說明手冊。

### 關於

1. 在開機碟製作器介面，單擊 ![icon_menu](../common/icon_menu.svg)。
2. 單擊 **關於**。
3. 查看關於開機碟製作器的版本和介紹。

### 離開

1. 在開機碟製作器介面，單擊 ![icon_menu](../common/icon_menu.svg)。
2. 單擊 **離開**。
